Learn R Programming

MLwrap (version 0.3.0)

table_integrated_gradients_results: Integrated Gradients Summarized Results Table

Description

The table_integrated_gradients_results() function implements a summarized metrics scheme for Integrated Gradients values. This methodology, specifically designed for neural networks, calculates feature importance through gradient integration along paths from baseline to input. Three different metrics are computed:

  • Mean Absolute Value

  • Standard Deviation of Mean Absolute Value

  • Directional Sensitivity Value (Cov(Feature values, IG values) / Var(Feature values))

Usage

table_integrated_gradients_results(analysis_object, show_table = FALSE)

Value

Tibble or list of tibbles (multiclass classification) with Integrated Gradient summarized results.

Arguments

analysis_object

Fitted analysis_object with 'sensitivity_analysis(methods = "Integrated Gradients")'.

show_table

Boolean. Whether to print the table.

See Also

sensitivity_analysis

Examples

Run this code
# Note: For obtaining the table with Integrated Gradients method results
# the user needs to complete till sensitivity_analysis() function of the
# MLwrap pipeline using the Integrated Gradient method.
# See the full pipeline example under sensitivity_analysis
# (Requires sensitivity_analysis(methods = "Integrated Gradients"))
# Final call signature:
# table_integrated_gradients_results(wrap_object)

Run the code above in your browser using DataLab